aboutsummaryrefslogtreecommitdiffstats
path: root/src/vlib/unix/main.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/vlib/unix/main.c')
-rw-r--r--src/vlib/unix/main.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/vlib/unix/main.c b/src/vlib/unix/main.c
index 568876b2933..95aeecf2da2 100644
--- a/src/vlib/unix/main.c
+++ b/src/vlib/unix/main.c
@@ -180,8 +180,8 @@ unix_signal_handler (int signum, siginfo_t * si, ucontext_t * uc)
/* have to remove SIGABRT to avoid recursive - os_exit calling abort() */
unsetup_signal_handlers (SIGABRT);
- /* os_exit(1) causes core generation, do not do this for SIGINT */
- if (signum == SIGINT)
+ /* os_exit(1) causes core generation, skip that for SIGINT, SIGHUP */
+ if (signum == SIGINT || signum == SIGHUP)
os_exit (0);
else
os_exit (1);